__all__ = (
    "__title__", "__summary__", "__uri__", "__version__", "__author__",
    "__email__", "__license__", "__copyright__",
)

__title__ = "zk-rn-lib-maker"
__summary__ = "create react-native lib for zhike"
__uri__ = "https://gitee.com/smartstudy/zk_rn_lib_maker.git"

__version__ = "1.0.0"

__author__ = "JeffreyCao"
__email__ = "je255reycao@outlook.com"

__license__ = "MIT Licence"
__copyright__ = "Copyright 2019 JeffreyCao"
